aboutsummaryrefslogtreecommitdiff
path: root/classes/CinisisDb.php
diff options
context:
space:
mode:
Diffstat (limited to 'classes/CinisisDb.php')
-rw-r--r--classes/CinisisDb.php10
1 files changed, 7 insertions, 3 deletions
diff --git a/classes/CinisisDb.php b/classes/CinisisDb.php
index eb09f9e..3a5ab4a 100644
--- a/classes/CinisisDb.php
+++ b/classes/CinisisDb.php
@@ -122,7 +122,8 @@ class CinisisDb {
* Get a file path.
*
* @param $config
* Config file name (either relative to the library or absolute).
*
* @param $section
* Config file section (ignored for absolute files).
@@ -131,8 +132,11 @@ class CinisisDb {
* Return the assembled file path.
*/
public function file($config = NULL, $section = 'config') {
- // Check for NULL or relative config path.
- if ($config == NULL) {
+ // Check config format (array, NULL or relative config path).
+ if (is_array($config)) {
+ return $config;
+ }
+ elseif ($config == NULL) {
$config = "$section/config.yaml";
}
elseif (substr($config, 0, 1) != '/') {
@@ -122,7 +122,8 @@ class CinisisDb {
*
* @param $config
- * Config file name (either relative to the library or absolute).
+ * Config file name (either relative to the library or absolute)
+ * or array with configuration.
*
* @param $section